@@ -6,7 +6,7 @@ class BaseOutputDevice:
         self.sampling_rate = sampling_rate
         self.audio_encoding = audio_encoding
 
-    async def send_async(self, chunk):
+    async def send_async(self, chunk: bytes):
         raise NotImplemented
 
     async def maybe_send_mark_async(self, message):
